@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::Import::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Git::CPAN::Patch::Command::Import::VERSION = '1.0.0';
+  $Git::CPAN::Patch::Command::Import::VERSION = '1.0.1';
 }
 #ABSTRACT: Import a module into a git repository
 
@@ -243,13 +243,13 @@ __END__
 
     # takes any string CPANPLUS handles:
 
-    % git cpan-import Foo::Bar
-    % git cpan-import A/AU/AUTHORID/Foo-Bar-0.03.tar.gz
-    % git cpan-import http://backpan.cpan.org/authors/id/A/AU/AUTHORID/Foo-Bar-0.03.tar.gz
+    % git-cpan import Foo::Bar
+    % git-cpan import A/AU/AUTHORID/Foo-Bar-0.03.tar.gz
+    % git-cpan import http://backpan.cpan.org/authors/id/A/AU/AUTHORID/Foo-Bar-0.03.tar.gz
 
     # If the repository is already initialized, can be run with no arguments to
     # import the latest version
-    git cpan-import
+    git-cpan import
 
 
 =head1 DESCRIPTION
@@ -295,7 +295,7 @@ For example, this will set the current HEAD of the master branch as a parent of
 the imported CPAN package:
 
     $ git checkout master
-    $ git cpan-import --parent HEAD My-Module
+    $ git-cpan import --parent HEAD My-Module
 
 More than one '--parent' can be specified.
 
